@@ -95,7 +95,7 @@ class Logon:  # pylint: disable=too-many-instance-attributes
         self._asp_net_id: Final[str] = client.cookies["ASP.NET_SessionId"]
         if compass_props.master.sys.session_id is None:
             raise ci.CompassError("ASP.NET ID must be specified!")
-        self._session_id: Final[str] = compass_props.master.sys.session_id
+        self._session_id: Final[str] = compass_props.master.sys.session_id  # session ID is an RFC 4122 UUID string
 
         # TODO session timeout logic
 
@@ -153,7 +153,7 @@ class Logon:  # pylint: disable=too-many-instance-attributes
         Args:
             asp_net_id: ASP.NET Session ID, from cookie
             user_props: Compass master.sys.user properties
-            session_id: Compass session UID
+            session_id: Compass session RFC 4122 UUID string
             current_role: Role used by initialised session
 
         Returns:
@@ -161,7 +161,7 @@ class Logon:  # pylint: disable=too-many-instance-attributes
 
         """
         client = Client()
-        client.cookies.set("ASP.NET_SessionId", asp_net_id, domain=Settings.base_domain)  # type: ignore[no-untyped-call]
+        client.cookies.set("ASP.NET_SessionId", asp_net_id, domain=Settings.base_domain)
 
         logon = cls(
             client=client,
@@ -175,7 +175,7 @@ class Logon:  # pylint: disable=too-many-instance-attributes
 
     def __repr__(self) -> str:
         """String representation of the Logon class."""
-        return f"{self.__class__} Compass ID: {self.membership_number} ({' - '.join(self.current_role)})"
+        return f"<{self.__class__.__name__}> Compass ID: {self.membership_number} ({' - '.join(self.current_role)})"
 
     def _extend_session_timeout(self, sto: _TYPES_STO = "0") -> str:
         # Session time out. 4 values: None (normal), 0 (STO prompt) 5 (Extension, arbitrary constant) X (Hard limit)
@@ -185,7 +185,7 @@ class Logon:  # pylint: disable=too-many-instance-attributes
             (self.membership_number, self.role_number, self._jk),
             self._client,
             f"{Settings.web_service_path}/STO_CHK",
-            params={"pExtend": sto},
+            params={"pExtend": sto},  # type: ignore[dict-item]
         )
         return response.content.decode("utf-8")
 
@@ -233,7 +233,7 @@ def _create_session() -> Client:
     """Create a session and get ASP.Net Session ID cookie from the compass server."""
     client = Client()
 
-    client.head(f"{Settings.base_url}/")  # use .head() as only headers needed to grab session cookie
+    client.head(f"{Settings.base_url}/", allow_redirects=False)  # use .head() as only headers needed to grab session cookie
     Settings.total_requests += 1
 
     if not client.cookies:
@@ -342,13 +342,6 @@ def _roles_iterator(form_tree: html.FormElement) -> Iterator[tuple[int, ci.TYPES
             yield int(row.get("data-pk")), (row[0].text_content().strip(), row[2].text_content().strip())
 
 
-def _update_auth_headers(
-    client: Client,
-    membership_number: int,
-    role_number: int,
-    session_id: str,
-) -> None:
-    client.headers.update(
-        Authorization=f"{membership_number}~{role_number}",
-        SID=session_id,  # Session ID
-    )
+def _update_auth_headers(client: Client, membership_number: int, role_number: int, session_id: str) -> None:
+    client.headers["Authorization"] = f"{membership_number}~{role_number}"
+    client.headers["SID"] = session_id  # Session ID
